@@ -1,4 +1,4 @@
-bootstrap_helper = function (i, m, xmins, pars, data_max) {
+bootstrap_helper = function (i, m, xmins, pars) {
   x = sample(m$dat, length(m$dat), replace=TRUE)
   
   m_cpy = m$getRefClass()$new(x)
@@ -7,11 +7,10 @@ bootstrap_helper = function (i, m, xmins, pars, data_max) {
 
 #' @rdname estimate_xmin
 #' @export
-bootstrap = function (m, xmins=NULL, pars=NULL, 
-                        no_of_sims=100, threads=1,
-                        data_max=1e5) {
+bootstrap = function (m, xmins=1e5, pars=NULL, 
+                        no_of_sims=100, threads=1) {
   m_cpy = m$copy()
-  gof_v = estimate_xmin(m_cpy, xmins=xmins, pars=pars, data_max=data_max)
+  gof_v = estimate_xmin(m_cpy, xmins=xmins, pars=pars)
   m_cpy$setXmin(gof_v)
   x = m_cpy$dat
   N = length(x)
@@ -22,7 +21,7 @@ bootstrap = function (m, xmins=NULL, pars=NULL,
   clusterExport(cl, c("estimate_xmin"))
   nof = parSapply(cl, 1:no_of_sims,
                   bootstrap_helper,  m_cpy, 
-                  xmins, pars, data_max)
+                  xmins, pars)
   stopCluster(cl)
   end_time = Sys.time()
   
