@@ -13,33 +13,51 @@ get_KS_statistic = function(m) {
 }
 
 
-#' Estimates the lower bound (xmin)
+#' Estimating the lower bound (xmin)
 #' 
-#' When fitting heavy tailed distributions, sometimes it is necessary to estimate the lower threshold, xmin. The
-#' lower bound is estimated by calculating the minimising the Kolmogorov-Smirnoff statistic 
+#' When fitting heavy tailed distributions, sometimes it 
+#' is necessary to estimate the lower threshold, xmin. The
+#' lower bound is estimated by calculating the minimising the
+#' Kolmogorov-Smirnoff statistic 
 #' (as described in Clauset, Shalizi, Newman (2009)).
 #' \describe{
 #' \item{\code{get_KS_statistic}}{Calculates the KS statistic for a particular value of xmin}
 #' \item{\code{estimate_xmin}}{Estimates the optimal lower cutoff using a 
 #' goodness-of-fit based approach. This function may issue \code{warnings} 
 #' when fitting lognormal, Poisson or Exponential distributions. The 
-#' warnings occur for large values of xmin. Essentially, we are discarding 
-#' the bult of the distribution and cannot calculate the tails to enough
+#' warnings occur for large values of \code{xmin}. Essentially, we are discarding 
+#' the bulk of the distribution and cannot calculate the tails to enough
 #' accuracy.}
 #' \item{\code{bootstrap}}{Estimates the unncertainity in the xmin and parameter values via bootstraping.}
 #' \item{\code{bootstrap_p}}{Performs a bootstrapping hypothesis test to determine whether a power law
 #' distribution is plausible. This function only available for power law distribution objects.}}
 #' @param m A reference class object that contains the data.
-#' @param pars default NULL. A vector of parameters used to optimise over. 
-#' Otherwise, for each value of xmin, the mle will be used, i.e. \code{estimate_pars(m)}.
+#' @param pars default \code{NULL}. A vector of parameters used to 
+#' optimise over. 
+#' Otherwise, for each value of \code{xmin}, the mle will be used, i.e. \code{estimate_pars(m)}.
 #' For small samples, the mle may be biased. 
-#' @param xmins default NULL. A vector of possible values of xmin to explore. 
-#' The default, \code{xmins=NULL}, results in exploring all possible xmin values.
-#' @param data_max default 1e5. When estimating xmin for discrete distributions, 
-#' the search space when comparing the data_cdf and distribution_cdf runs from 1:data_max
+#' @param xmins default \code{1e5}. A vector of possible values 
+#' of xmin to explore. When a single value is passed, this represents
+#' the maximum value to search, i.e. by default we search from
+#' (1, 1e5). See details for further information.
 #' @param threads number of concurrent threads used during the bootstrap.
 #' @param no_of_sims number of bootstrap simulations. When \code{no_of_sims} is large, this can 
 #' take a while to run.
+#' @details When estimating \code{xmin}
+#' for discrete distributions, the search space when 
+#' comparing the data-cdf (empirical cdf)
+#' and the distribution_cdf runs from 1 to \code{max(x)}
+#' where \code{x} is the data set. This \strong{can} often be 
+#' computationally brutal. In particular, when bootstrapping
+#' we generate random numbers from the power law distribution, 
+#' which has a long tail. 
+#' 
+#' To speed up computations for discrete distributions, it is sensible to put an 
+#' upper bound or explicitly give values of where to search. 
+#' If a single value is used in \code{xmins}, this will be used 
+#' as the maximum search space value. 
+#' If \code{length(xmins) > 1}, this will explicitly
+#' define the search space.
 #' @importFrom parallel makeCluster parSapply 
 #' @importFrom parallel clusterExport stopCluster
 #' @note Adapted from Laurent Dubroca's code found at
@@ -64,26 +82,34 @@ get_KS_statistic = function(m) {
 #' bootstrap(m, no_of_sims=1, threads=1)
 #' bootstrap_p(m, no_of_sims=1, threads=1)
 estimate_xmin = function (m, 
-                          xmins = NULL, 
-                          pars=NULL,
-                          data_max = 1e5) {
+                          xmins = 1e5, 
+                          pars=NULL) {
   ##Make thread safe
   m_cpy = m$getRefClass()$new(m$dat)
-  if(is.null(xmins)) xmins = unique(m$dat)
-  
-  ## xmin scan
-  nr = length(xmins) - m_cpy$no_pars - 1
-  nr = min(data_max, nr)
-  dat = matrix(0, nrow=nr, ncol=(1 + m_cpy$no_pars))
-  
-  xm = 1
-  ##Initialise
-  est = estimate_pars(m_cpy)$pars
   m_cpy$pars = pars
+  if(length(xmins) == 1) {
+    space = unique(m$dat)
+    space = space[space <= xmins]
+    xmins = space
+  }
   
-  for(xm in 1:nr){
-   
-    m_cpy$xmin = xmins[xm]
+  ## Initialise xmin scan
+  nr = length(xmins) - m_cpy$no_pars - 1
+  
+  ## Bootstrapping may generate strange data
+  if(nr < m_cpy$no_pars || length(unique(m$dat)) == 1L) {
+    ## Insufficient data to estimate parameters
+    dat = matrix(0, nrow=1, ncol=(1 + m_cpy$no_pars))
+    dat[1,] = c(Inf, rep(NA, m_cpy$no_pars))
+  } else {
+    dat = matrix(0, nrow=nr, ncol=(1 + m_cpy$no_pars))   
+    est = estimate_pars(m_cpy)$pars
+  }
+
+  xm = 0L
+  while(nr >= m_cpy$no_pars && xm < nr)   {
+    #for(xm in 1:nr){
+    m_cpy$xmin = xmins[xm + 1L]
     if(is.null(pars)) m_cpy$mle(initialise=est)
     else m_cpy$pars = pars
     
@@ -94,15 +120,15 @@ estimate_xmin = function (m,
       m_cpy$pars = m_cpy$pars[I]
     }
     gof = get_KS_statistic(m_cpy)
-    dat[xm,] = c(gof, m_cpy$pars)
+    dat[xm <- xm + 1L,] = c(gof, m_cpy$pars)
   }
   
-  I = which.min(dat[,1])
+  I = which.min(dat[,1L])
   xmin = xmins[I]
-  n = sum(m_cpy$dat >= xmin)
-  pars = dat[I,2:ncol(dat)]
+ # n = sum(m_cpy$dat >= xmin)
+  pars = dat[I, 2:ncol(dat)]
   
-  l = list(KS=dat[I,1], xmin=xmin, pars=pars)
+  l = list(KS=dat[I, 1L], xmin=xmin, pars=pars)
   class(l) = "estimate_xmin"
   return(l)
 }
